FileAsset class

Implementers

Constructors

FileAsset({required String dirPath, required String resId, required List<String> assetFiles, ResourceQualifiers? spec, bool? onlyUseAsset})
const

Properties

assetFiles List<String>
final
dirPath String
final
hashCode int
The hash code for this object.
no setterinherited
onlyUseAsset bool?
final
pathId PathId
no setter
resId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spec ResourceQualifiers?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited