FileAssetImage class

Inheritance

Constructors

FileAssetImage({required String dirPath, required String resId, required List<String> assetFiles, ResourceQualifiers? spec, bool? onlyUseAsset})

Properties

assetFiles List<String>
finalinherited
dirPath String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
onlyUseAsset bool?
finalinherited
pathId PathId
no setterinherited
resId String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spec ResourceQualifiers?
finalinherited

Methods

image({Key? key, ImageFrameBuilder? frameBuilder, ImageErrorWidgetBuilder? errorBuilder, String? semanticLabel, bool excludeFromSemantics = false, double? scale, double? width, double? height, Color? color, Animation<double>? opacity, BlendMode? colorBlendMode, BoxFit? fit, AlignmentGeometry alignment = Alignment.center, ImageRepeat repeat = ImageRepeat.noRepeat, Rect? centerSlice, bool matchTextDirection = false, bool gaplessPlayback = false, bool isAntiAlias = false, AssetBundle? bundle, String? package, FilterQuality filterQuality = FilterQuality.low, int? cacheWidth, int? cacheHeight}) Image
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
provider({String? package, AssetBundle? bundle}) ImageProvider<Object>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited