FileLottieImage class

Inheritance

Constructors

FileLottieImage({required String dirPath, required String resId, required List<String> assetFiles, ResourceQualifiers? spec, bool? onlyUseAsset})

Properties

assetFiles List<String>
finalinherited
dirPath String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
onlyUseAsset bool?
finalinherited
pathId PathId
no setterinherited
resId String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spec ResourceQualifiers?
finalinherited

Methods

lottie({Animation<double>? controller, bool? animate, FrameRate? frameRate, bool? repeat, bool? reverse, LottieDelegates? delegates, LottieOptions? options, void onLoaded(LottieComposition)?, LottieImageProviderFactory? imageProviderFactory, Key? key, AssetBundle? bundle, Widget frameBuilder(BuildContext, Widget, LottieComposition?)?, ImageErrorWidgetBuilder? errorBuilder, double? width, double? height, BoxFit? fit, AlignmentGeometry? alignment, String? package, bool? addRepaintBoundary, FilterQuality? filterQuality, void onWarning(String)?}) → LottieBuilder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited