FileSvgImage class

Inheritance

Constructors

FileSvgImage({required String dirPath, required String resId, required List<String> assetFiles, ResourceQualifiers? spec, bool? onlyUseAsset})

Properties

assetFiles List<String>
finalinherited
dirPath String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
onlyUseAsset bool?
finalinherited
pathId PathId
no setterinherited
resId String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spec ResourceQualifiers?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
svg({Key? key, bool matchTextDirection = false, AssetBundle? bundle, String? package, double? width, double? height, BoxFit fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center, bool allowDrawingOutsideViewBox = false, WidgetBuilder? placeholderBuilder, String? semanticsLabel, bool excludeFromSemantics = false, SvgTheme? theme, ColorFilter? colorFilter, Clip clipBehavior = Clip.hardEdge, Color? color, BlendMode colorBlendMode = BlendMode.srcIn, bool cacheColorFilter = false}) → SvgPicture
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited