ResourceQualifiers class

Constructors

ResourceQualifiers(Map<String, dynamic> qualifiers)
factory
ResourceQualifiers.empty()
factory
ResourceQualifiers.from(ResourceQualifiers other)
factory

Properties

entries Iterable<MapEntry<String, dynamic>>
no setter
hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
no setter
isNotEmpty bool
no setter
keys Iterable<String>
no setter
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Iterable
no setter

Methods

containsAllKeys(Iterable<String> keys) bool
containsKey(String key) bool
containsValue(dynamic value) bool
copyWith(Map<String, dynamic> additionalQualifiers) ResourceQualifiers
copyWithout(Iterable<String> keysToRemove) ResourceQualifiers
get<T>(String key) → T?
getOrDefault<T>(String key, T defaultValue) → T
matches(Map<String, dynamic> qualifiers) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Properties

cacheSize int
no setter

Static Methods

clearCache() → void
merge(List<ResourceQualifiers> qualifiersList) ResourceQualifiers