ResourceValue class
Constructors
- ResourceValue({required String resFileId, required String resourceName, ResourceQualifiers? spec, bool? onlyUseAsset})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onlyUseAsset → bool?
-
final
- resFileId → String
-
final
- resourceName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spec → ResourceQualifiers?
-
final
Methods
-
boolValue(
{bool? defaultValue}) → bool? -
color(
{Color? defaultValue}) → Color? -
doubleValue(
{double? defaultValue}) → double? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
string(
{String? defaultValue}) → String? -
stringArray(
{List< String> ? defaultValue}) → List<String> ? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited