FileAssetLoader class
Constructors
- FileAssetLoader()
-
factory
Properties
- config → FileAssetConfig
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skinDir ↔ String?
-
getter/setter pair
Methods
-
files(
String dirPath, String resId) → List< String> -
getResValue(
{required String resFileId, required String resourceName, required ValueType valueType, required ResourceQualifiers spec, bool? onlyUseAsset, required dynamic defaultValue}) → dynamic -
init(
FileAssetConfig config) → void -
load(
String skinDir) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited